import 'dart:developer';
import 'dart:io';

import 'package:flutter/material.dart';
import 'dart:async';

import 'package:cs_ayetstudios_ad/cs_ayetstudios_ad.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatefulWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  State<MyApp> createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  @override
  void initState() {
    super.initState();
    initSDK();
  }

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> initSDK() async {
    try {
      if (Platform.isAndroid) {
        CsAyetstudiosAndroid().initSDK(uid: 'android uid');
        CsAyetstudiosAndroid().setUserBalanceChangedListener(userBalanceChanged);
        CsAyetstudiosAndroid().setInitializationSuccessListener(initializationSuccess);
        CsAyetstudiosAndroid().setInitilizationFailedListener(initilizationFailed);
        CsAyetstudiosAndroid().setVideoAbortedListener(videoAborted);
        CsAyetstudiosAndroid().setVideoCompletedListener(videoCompleted);
        CsAyetstudiosAndroid().setVideoNofillListener(videoNofill);
        CsAyetstudiosAndroid().setVideoFinishedListener(videoFinished);
        CsAyetstudiosAndroid().setVideoWillBeShownListener(videoWillBeShown);
      } else if (Platform.isIOS) {
        CsAyetstudiosIos().sdkLogEnable();
        CsAyetstudiosIos().initSDK(appKey: 'ios app key', uid: 'ios uid');
        CsAyetstudiosIos().setUserBalanceChanged(userBalanceChanged);
        CsAyetstudiosIos().userAvailableBalance();
        CsAyetstudiosIos().userPendingBalance();
      }
    } catch (e) {
      log("初始化SDK失败:" + e.toString());
    }
  }

  /// 用户积分发生变化
  void userBalanceChanged(int balance) {}

  /// SDK初始化成功
  void initializationSuccess(int balance, int spent, int pending) {}

  /// SDK初始化失败
  void initilizationFailed() {}

  /// 视频放弃 或者跳过
  void videoAborted() {}

  /// 看完完整视频获得奖励回调
  void videoCompleted(int amount) {}

  /// 没有获得视频奖励可以展示
  void videoNofill() {}

  /// 所有视频活动完成时都会调用(视频完成，中止或其他问题，如网络速度)
  void videoFinished() {}

  /// 择一个视频之后和视频活动开始播放它之前被调用
  void videoWillBeShown() {}

  void initializationFailed(int failed) {
    print('Ayetstudios", "initializationFailed $failed');
  }

  void userAvailableBalance(int balance) {
    print('Ayetstudios available balance = $balance');
  }

  void userPendingBalance(int balance) {
    print('AyetSdk pending balance = $balance');
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: const Center(child: Text('测试初始化Ayetstudios SDK')),
      ),
    );
  }
}
